@@ -44,7 +44,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> '預設語言',
 	'DEFAULT_STYLE'					=> '預設風格',
 	'DISABLE_BOARD'					=> '關閉討論區',
-	'DISABLE_BOARD_EXPLAIN'			=> '這個動作將使會員無法連結討論區。如果您希望，那麼您也可以輸入一段簡短的 (最多 255 個字元) 訊息去顯示。',
+	'DISABLE_BOARD_EXPLAIN'			=> '這將使得會員無法使用討論區，但管理員或版主除外。如果您希望，那麼您也可以輸入一段簡短的 (最多 255 個字元) 訊息去顯示。',
 	'OVERRIDE_STYLE'				=> '覆蓋會員風格',
 	'OVERRIDE_STYLE_EXPLAIN'		=> '用討論區的預設風格取代會員的風格。',
 	'SITE_DESC'						=> '討論區描述',
@@ -104,7 +104,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> '系統相簿路徑',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> '該路徑必須在 phpBB 的根目錄內，例如：<samp>images/avatars/gallery</samp>。',
 	'AVATAR_STORAGE_PATH'			=> '頭像儲存路徑',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> '該路徑必須在 phpBB 的根目錄內，例如：<samp>images/avatars/upload</samp>。',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> '該路徑必須在 phpBB 的根目錄內，例如：<samp>images/avatars/upload</samp>。<br />如果該路徑無法寫入，頭像上傳<strong>將無法使用</strong>。',
 	'MAX_AVATAR_SIZE'				=> '頭像尺寸最大限制',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> '寬 x 高 (像素)。',
 	'MAX_FILESIZE'					=> '頭像檔案大小限制',
