@@ -50,7 +50,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN'					=> '封鎖',
 	'ACP_BAN_EMAILS'			=> '封鎖的 e-mail',
 	'ACP_BAN_IPS'				=> '封鎖的 IP',
-	'ACP_BAN_USERNAMES'			=> '封鎖的會員名稱',
+	'ACP_BAN_USERNAMES'			=> '封鎖的會員',
 	'ACP_BBCODES'				=> 'BBCodes',
 	'ACP_BOARD_CONFIGURATION'	=> '討論區基本組態',
 	'ACP_BOARD_FEATURES'		=> '討論區特色',
