@@ -88,9 +88,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'	=> '上傳的檔案只上傳了一部分。',
 	'AVATAR_PHP_SIZE_NA'	=> '頭像檔案太大。<br />無法判斷伺服器 PHP 允許的最大檔案大小限制。',
 	'AVATAR_PHP_SIZE_OVERRUN'	=> '頭像檔案太大，伺服器允許的最大檔案大小是 %1$d %2$s。<br />請注意這個限制是根據伺服器上 php.ini 的設定，所以無法變更。',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> '指定的頭像無法上傳，因為請求逾時。',
 	'AVATAR_URL_INVALID'	=> '指定的連結無效。',
 	'AVATAR_URL_NOT_FOUND'	=> '無法找到指定的檔案。',
-	'AVATAR_WRONG_FILESIZE'	=> '頭像檔案大小必須介於 0 和 %1d %2s 之間。',
+	'AVATAR_WRONG_FILESIZE'			=> '頭像檔案大小必須介於 0 和 %1$d %2$s 之間。',
 	'AVATAR_WRONG_SIZE'	=> '頭像的寬度必須大於 %1$d 像素，高度必須大於 %2$d 像素，並且寬度不得超過 %3$d 像素，高度不得超過 %4$d 像素。您送出的頭像寬為 %5$d 像素，高為 %6$d 像素。',
 
 	'BACK_TO_TOP'	=> '回頂端',
@@ -341,6 +342,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'	=> '管理',
 	'MODERATOR'	=> '版主',
 	'MODERATORS'	=> '版主',
+	'MODULE_NOT_ACCESS'		=> '模組無法使用',
+	'MODULE_NOT_FIND'		=> '不能找到模組 %s',
+	'MODULE_FILE_INCORRECT_CLASS'	=> '模組檔案 %s 不包含正確的等級 [%s]',
 	'MONTH'	=> '月',
 	'MOVE'	=> '移動',
 	'MSNM'					=> 'MSNM/WLM',
@@ -651,7 +655,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> '會員總數：<strong>0</strong>',
 	'TRACKED_PHP_ERROR'	=> '已追蹤 PHP 錯誤：%s',
 
-	'UNABLE_GET_IMAGE_SIZE'	=> '無法瀏覽圖檔，或者此檔案不是一個有效的圖檔。',
+	'UNABLE_GET_IMAGE_SIZE'	=> '要確定圖像的尺寸是不可能的。請確認您輸入的網址是否正確。',
 	'UNABLE_TO_DELIVER_FILE'	=> '無法傳送檔案。',
 	'UNKNOWN_BROWSER'	=> '無法瀏覽',
 	'UNMARK_ALL'	=> '取消全選',
@@ -721,8 +725,8 @@ $lang = array_merge($lang, array(
 	'WHOIS'				=> 'Whois',
 	'WHO_IS_ONLINE'	=> '誰在線上',
 	'WRONG_PASSWORD'	=> '您輸入了錯誤的密碼。',
-	'WRONG_DATA_COLOUR'			=> '您輸入的顏色值是無效的。',
 
+	'WRONG_DATA_COLOUR'			=> '您輸入的顏色值是無效的。',
 	'WRONG_DATA_ICQ'	=> '您輸入的數字不是一個有效的 ICQ 號碼。',
 	'WRONG_DATA_JABBER'	=> '您輸入的名字不是一個有效的 Jabber 帳號。',
 	'WRONG_DATA_LANG'	=> '您指定了一個無效的語言。',
